@@ -3,8 +3,8 @@ PdfInfoExtractor
 
 """
 
-from PdfInfoExtractor import *
+from PdfInfoExtractor import ImagesExtractor, ClassifyFiles, extract_info
 
-__version__ = "0.1.8"
+__version__ = "0.1.9"
 __author__ = 'Steve Richards, Mehak Singal, Nidhish Kumar'
 # __credits__ = 'Argonne National Laboratory'
\ No newline at end of file
